@@ -411,12 +411,11 @@ class ImpalaAdapter(SQLAdapter):
 
     def debug_query(self) -> None:
         self.execute("select 1 as id")
+        username = ""
         try:
             username = self.config.credentials.username
-            # for impala schema/database name are the same
-            database = self.config.credentials.schema
-            sql_query = "show grant user `" + username + "` on database " + database
-            response, table = self.execute(sql_query, True, True)
+            sql_query = "show grant user `" + username + "` on server"
+            _, table = self.execute(sql_query, True, True)
             permissions_object = []
             json_funcs = [c.jsonify for c in table.column_types]
 
@@ -427,13 +426,12 @@ class ImpalaAdapter(SQLAdapter):
             permissions_json = json.dumps(permissions_object)
 
             payload = {
-                "event_type": "dbt_debug_and_fetch_permissions",
+                "event_type": "dbt_impala_debug_and_fetch_permissions",
                 "permissions": permissions_json,
             }
             tracker.track_usage(payload)
         except Exception as ex:
             logger.debug(
-                "Failed to fetch permissions for user: {}. Exception: {}".format(
-                    username, ex
-                )
+                f"Failed to fetch permissions for user: {username}. Exception: {ex}"
             )
+            self.connections.get_thread_connection().handle.close()
