@@ -129,12 +129,24 @@
     {{ return(load_result('list_schemas').table) }}
 {% endmacro %}
 
+{# Note: This function currently needs to query each object to determine its type. Depending on the schema, this function could be expensive. #}
 {% macro impala__list_relations_without_caching(relation) %}
-  {% call statement('list_relations_without_caching', fetch_result=True) -%}
-    show tables in {{ relation }}
-  {% endcall %}
+  {% set result_set = run_query('show tables in ' ~ relation) %}
+  {% set objects_with_type = [] %}
 
-  {% do return(load_result('list_relations_without_caching').table) %}
+  {%- for rs in result_set -%}
+    {% set obj_type = [] %}
+
+    {% do obj_type.append(rs[0]) %}
+
+    {% set obj_rel = relation.new_copy(relation.schema, rs[0]) %}
+    {% set rel_type = get_relation_type(obj_rel) %}
+    {% do obj_type.append(rel_type) %}
+
+    {% do objects_with_type.append(obj_type) %}
+  {%- endfor -%}
+
+  {{ return(objects_with_type) }}
 {% endmacro %}
 
 {% macro impala__create_table_as(temporary, relation, sql) -%}
@@ -188,10 +200,12 @@
 {% endmacro %}
 
 {% macro impala__drop_relation(relation) -%}
-  {% set rel_type = get_relation_type(relation) %}
-  {% call statement('drop_relation', auto_begin=False) -%}
-    drop {{ rel_type }} if exists {{ relation }}
-  {%- endcall %}
+  {% call statement('drop_relation_if_exists_table') %}
+    drop table if exists {{ relation }}
+  {% endcall %}
+  {% call statement('drop_relation_if_exists_view') %}
+    drop view if exists {{ relation }}
+  {% endcall %}
 {% endmacro %}
 
 {% macro is_relation_present(relation) -%}
@@ -237,8 +251,11 @@
 {% macro impala__rename_relation(from_relation, to_relation) -%}
   {% set from_rel_type = get_relation_type(from_relation) %}
   
-  {% call statement('drop_relation') %}
-    drop {{ from_rel_type }} if exists {{ to_relation }}
+  {% call statement('drop_relation_if_exists_table') %}
+    drop table if exists {{ to_relation }}
+  {% endcall %}
+  {% call statement('drop_relation_if_exists_view') %}
+    drop view if exists {{ to_relation }};
   {% endcall %}
   {% call statement('rename_relation') -%}
     {% if not from_rel_type %}
@@ -316,6 +333,10 @@
     insert into {{target_relation}} ({{insert_cols_csv}}) select {{insert_cols_csv}} from {{staging_table}}
 {% endmacro %}
 
+{% macro impala__generate_database_name(custom_database_name=none, node=none) -%}
+  {% do return(None) %}
+{%- endmacro %}
+
 /* snapshots flow for impala */
 {% materialization snapshot, adapter='impala' %}
   {%- set config = model['config'] -%}
